/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgDraft.idl
 */

#ifndef __gen_nsIMsgDraft_h__
#define __gen_nsIMsgDraft_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIOutputStream_h__
#include "nsIOutputStream.h"
#endif

#ifndef __gen_nsIMsgIdentity_h__
#include "nsIMsgIdentity.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsIMsgDraft */
#define NS_IMSGDRAFT_IID_STR "a6237474-453b-11d3-8f0f-00a024a7d144"

#define NS_IMSGDRAFT_IID \
  {0xa6237474, 0x453b, 0x11d3, \
    { 0x8f, 0x0f, 0x00, 0xa0, 0x24, 0xa7, 0xd1, 0x44 }}

class NS_NO_VTABLE nsIMsgDraft : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGDRAFT_IID)

  /* void OpenDraftMsg (in string msgURI, in string originalMsgURI, in nsIMsgIdentity identity, in PRBool addInlineHeaders, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD OpenDraftMsg(const char *msgURI, const char *originalMsgURI, nsIMsgIdentity *identity, PRBool addInlineHeaders, nsIMsgWindow *aMsgWindow) = 0;

  /* void OpenEditorTemplate (in string msgURI, in nsIMsgIdentity identity, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD OpenEditorTemplate(const char *msgURI, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGDRAFT \
  NS_IMETHOD OpenDraftMsg(const char *msgURI, const char *originalMsgURI, nsIMsgIdentity *identity, PRBool addInlineHeaders, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD OpenEditorTemplate(const char *msgURI, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGDRAFT(_to) \
  NS_IMETHOD OpenDraftMsg(const char *msgURI, const char *originalMsgURI, nsIMsgIdentity *identity, PRBool addInlineHeaders, nsIMsgWindow *aMsgWindow) { return _to OpenDraftMsg(msgURI, originalMsgURI, identity, addInlineHeaders, aMsgWindow); } \
  NS_IMETHOD OpenEditorTemplate(const char *msgURI, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow) { return _to OpenEditorTemplate(msgURI, identity, aMsgWindow); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGDRAFT(_to) \
  NS_IMETHOD OpenDraftMsg(const char *msgURI, const char *originalMsgURI, nsIMsgIdentity *identity, PRBool addInlineHeaders, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenDraftMsg(msgURI, originalMsgURI, identity, addInlineHeaders, aMsgWindow); } \
  NS_IMETHOD OpenEditorTemplate(const char *msgURI, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenEditorTemplate(msgURI, identity, aMsgWindow); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgDraft : public nsIMsgDraft
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGDRAFT

  nsMsgDraft();

private:
  ~nsMsgDraft();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgDraft, nsIMsgDraft)

nsMsgDraft::nsMsgDraft()
{
  /* member initializers and constructor code */
}

nsMsgDraft::~nsMsgDraft()
{
  /* destructor code */
}

/* void OpenDraftMsg (in string msgURI, in string originalMsgURI, in nsIMsgIdentity identity, in PRBool addInlineHeaders, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgDraft::OpenDraftMsg(const char *msgURI, const char *originalMsgURI, nsIMsgIdentity *identity, PRBool addInlineHeaders, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OpenEditorTemplate (in string msgURI, in nsIMsgIdentity identity, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgDraft::OpenEditorTemplate(const char *msgURI, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgDraft_h__ */
