/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIDocShellTreeItemTmp.idl
 */

#ifndef __gen_nsIDocShellTreeItemTmp_h__
#define __gen_nsIDocShellTreeItemTmp_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDocShellTreeItem; /* forward declaration */


/* starting interface:    nsIDocShellTreeItemTmp */
#define NS_IDOCSHELLTREEITEMTMP_IID_STR "9af94896-03fd-4646-bfc0-7b589cfe9dd5"

#define NS_IDOCSHELLTREEITEMTMP_IID \
  {0x9af94896, 0x03fd, 0x4646, \
    { 0xbf, 0xc0, 0x7b, 0x58, 0x9c, 0xfe, 0x9d, 0xd5 }}

/**
 * nsIDocShellTreeItemTmp is a temporary internal interface used only
 * to provide a changed signature for the findItemWithName() method to
 * fix problems where DOM windows were reachable across domains.
 */
class NS_NO_VTABLE nsIDocShellTreeItemTmp : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IDOCSHELLTREEITEMTMP_IID)

  /* nsIDocShellTreeItem findItemWithNameTmp (in wstring name, in nsISupports aRequestor, in nsIDocShellTreeItem aOriginalRequestor); */
  NS_IMETHOD FindItemWithNameTmp(const PRUnichar *name, nsISupports *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOCSHELLTREEITEMTMP \
  NS_IMETHOD FindItemWithNameTmp(const PRUnichar *name, nsISupports *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOCSHELLTREEITEMTMP(_to) \
  NS_IMETHOD FindItemWithNameTmp(const PRUnichar *name, nsISupports *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) { return _to FindItemWithNameTmp(name, aRequestor, aOriginalRequestor, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOCSHELLTREEITEMTMP(_to) \
  NS_IMETHOD FindItemWithNameTmp(const PRUnichar *name, nsISupports *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindItemWithNameTmp(name, aRequestor, aOriginalRequestor, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDocShellTreeItemTmp : public nsIDocShellTreeItemTmp
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOCSHELLTREEITEMTMP

  nsDocShellTreeItemTmp();

private:
  ~nsDocShellTreeItemTmp();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDocShellTreeItemTmp, nsIDocShellTreeItemTmp)

nsDocShellTreeItemTmp::nsDocShellTreeItemTmp()
{
  /* member initializers and constructor code */
}

nsDocShellTreeItemTmp::~nsDocShellTreeItemTmp()
{
  /* destructor code */
}

/* nsIDocShellTreeItem findItemWithNameTmp (in wstring name, in nsISupports aRequestor, in nsIDocShellTreeItem aOriginalRequestor); */
NS_IMETHODIMP nsDocShellTreeItemTmp::FindItemWithNameTmp(const PRUnichar *name, nsISupports *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDocShellTreeItemTmp_h__ */
