( cd usr/lib/mozilla-1.7.11 ; rm -rf libnspr4.so )
( cd usr/lib/mozilla-1.7.11 ; ln -sf ../libnspr4.so libnspr4.so )
( cd usr/lib/mozilla-1.7.11 ; rm -rf libplds4.so )
( cd usr/lib/mozilla-1.7.11 ; ln -sf ../libplds4.so libplds4.so )
( cd usr/lib/mozilla-1.7.11 ; rm -rf libplc4.so )
( cd usr/lib/mozilla-1.7.11 ; ln -sf ../libplc4.so libplc4.so )
( cd usr/lib/mozilla-1.7.11 ; rm -rf libsoftokn3.so )
( cd usr/lib/mozilla-1.7.11 ; ln -sf ../libsoftokn3.so libsoftokn3.so )
( cd usr/lib/mozilla-1.7.11 ; rm -rf libnss3.so )
( cd usr/lib/mozilla-1.7.11 ; ln -sf ../libnss3.so libnss3.so )
( cd usr/lib/mozilla-1.7.11 ; rm -rf libssl3.so )
( cd usr/lib/mozilla-1.7.11 ; ln -sf ../libssl3.so libssl3.so )
( cd usr/lib/mozilla-1.7.11 ; rm -rf libsmime3.so )
( cd usr/lib/mozilla-1.7.11 ; ln -sf ../libsmime3.so libsmime3.so )
