/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is the Mozilla browser.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1999 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Original Author: Marc Mulcahy (marc.mulcahy@sun.com)
 *
 * Contributor(s): Paul Sandoz (paul.sandoz@sun.com)
 *                 Bill Haneman (bill.haneman@sun.com)
 *                 John Gaunt (jgaunt@netscape.com)
 */

#include "nsISupports.idl"

[scriptable, uuid(829B36D4-125A-4279-ABC4-87D834664F82)]
interface nsIAccessibleAction : nsISupports
{
  readonly attribute long actions;

  boolean doAction (in long index);

  AString getDescription (in long index);
  void getDescriptionConst (in long index,
                            [shared, retval] out string description);

  AString getKeyBinding (in long index);
  void getKeyBindingConst (in long index,
                           [shared, retval] out string keyBinding);
};

/*
 Assumptions:

 string is a UTF-8 or most likely ASCII
 encoding.

*/
