/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is the Mozilla browser.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1999 Netscape Communications Corporation. All
 * Rights Reserved.
 * 
 * Contributor(s): 
 *   Stuart Parmenter <pavlov@netscape.com>
 */


#include "nsISupports.idl"

native int(int);
[ptr] native nsIEventQueue(nsIEventQueue);
[ptr] native UndefinednsIWidget(nsIWidget);
[ref] native PRBoolRef(PRBool);
[ref] native voidPtrRef(void *);

%{ C++
class nsIEventQueue;

/**
 * Flags for the getNativeData function.
 * See GetNativeData()
 */
#define NS_NATIVE_SHELL   0

class nsIWidget;
%}


[uuid(a0757c31-eeac-11d1-9ec1-00aa002fb821)]
interface nsIAppShell : nsISupports
{
 /**
  * Creates an application shell
  */ 

  void Create(inout int argc, inout string argv);

 /**
  * Enter an event loop.
  * Don't leave until application exits.
  */
  
  void Run();

 /**
  * Prepare to process events. 
  */
  
  void Spinup();

 /**
  * Prepare to stop processing events.  
  */
  
  void Spindown();

 /**
  * An event queue has been created or destroyed. Hook or unhook it from
  * your system, as necessary.
  * @param aQueue the queue in question
  * @param aListen PR_TRUE for a new queue wanting hooking up. PR_FALSE
  *                for a queue wanting to be unhooked.
  */
  void ListenToEventQueue(in nsIEventQueue aQueue, in PRBool aListen);

 /**
  * After event dispatch execute app specific code
  */
  
  void GetNativeEvent(in PRBoolRef aRealEvent, in voidPtrRef aEvent);

 /**
  * After event dispatch execute app specific code
  */
  
  void DispatchNativeEvent(in PRBool aRealEvent, in voidPtr aEvent);

 /**
  * Exit the handle event loop
  */

  void Exit();

};

#endif // nsIAppShell_h__


