/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 
 * The Original Code is mozilla.org code.
 
 * The Initial Developer of the Original Code is Netscape
 * Communications, Inc.  Portions created by Netscape are
 * Copyright (C) 2001, Mozilla.  All Rights Reserved.
 
 * Contributor(s):
 */

#include "nsISupports.idl"

[scriptable, uuid(28F16D80-157B-11d5-A542-0010A401EB10)]

/**
 * This interface defines a "permission" object,
 * used to specify allowed/blocked objects from
 * user-specified sites (cookies, images etc).
 */

interface nsIPermission : nsISupports
{
    /**
     * The name of the host for which the permission is set
     */
    readonly attribute AUTF8String host;

    /**
     * a case-sensitive ASCII string, indicating the type of permission
     * (e.g., "cookie", "image", etc).
     * This string is specified by the consumer when adding a permission 
     * via nsIPermissionManager.
     * @see nsIPermissionManager
     */
    readonly attribute ACString type;

    /**
     * The permission (see nsIPermissionManager.idl for allowed values)
     */
    readonly attribute PRUint32 capability;
};
