/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIDocShellTreeNodeTmp.idl
 */

#ifndef __gen_nsIDocShellTreeNodeTmp_h__
#define __gen_nsIDocShellTreeNodeTmp_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDocShellTreeItem; /* forward declaration */


/* starting interface:    nsIDocShellTreeNodeTmp */
#define NS_IDOCSHELLTREENODETMP_IID_STR "3fa20a60-e37f-42be-a6df-1c8d910742f1"

#define NS_IDOCSHELLTREENODETMP_IID \
  {0x3fa20a60, 0xe37f, 0x42be, \
    { 0xa6, 0xdf, 0x1c, 0x8d, 0x91, 0x07, 0x42, 0xf1 }}

class NS_NO_VTABLE nsIDocShellTreeNodeTmp : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IDOCSHELLTREENODETMP_IID)

  /* nsIDocShellTreeItem findChildWithNameTmp (in wstring aName, in boolean aRecurse, in boolean aSameType, in nsIDocShellTreeItem aRequestor, in nsIDocShellTreeItem aOriginalRequestor); */
  NS_IMETHOD FindChildWithNameTmp(const PRUnichar *aName, PRBool aRecurse, PRBool aSameType, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOCSHELLTREENODETMP \
  NS_IMETHOD FindChildWithNameTmp(const PRUnichar *aName, PRBool aRecurse, PRBool aSameType, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOCSHELLTREENODETMP(_to) \
  NS_IMETHOD FindChildWithNameTmp(const PRUnichar *aName, PRBool aRecurse, PRBool aSameType, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) { return _to FindChildWithNameTmp(aName, aRecurse, aSameType, aRequestor, aOriginalRequestor, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOCSHELLTREENODETMP(_to) \
  NS_IMETHOD FindChildWithNameTmp(const PRUnichar *aName, PRBool aRecurse, PRBool aSameType, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindChildWithNameTmp(aName, aRecurse, aSameType, aRequestor, aOriginalRequestor, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDocShellTreeNodeTmp : public nsIDocShellTreeNodeTmp
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOCSHELLTREENODETMP

  nsDocShellTreeNodeTmp();

private:
  ~nsDocShellTreeNodeTmp();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDocShellTreeNodeTmp, nsIDocShellTreeNodeTmp)

nsDocShellTreeNodeTmp::nsDocShellTreeNodeTmp()
{
  /* member initializers and constructor code */
}

nsDocShellTreeNodeTmp::~nsDocShellTreeNodeTmp()
{
  /* destructor code */
}

/* nsIDocShellTreeItem findChildWithNameTmp (in wstring aName, in boolean aRecurse, in boolean aSameType, in nsIDocShellTreeItem aRequestor, in nsIDocShellTreeItem aOriginalRequestor); */
NS_IMETHODIMP nsDocShellTreeNodeTmp::FindChildWithNameTmp(const PRUnichar *aName, PRBool aRecurse, PRBool aSameType, nsIDocShellTreeItem *aRequestor, nsIDocShellTreeItem *aOriginalRequestor, nsIDocShellTreeItem **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDocShellTreeNodeTmp_h__ */
