/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is the Mozilla browser.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications, Inc.  Portions created by Netscape are
 * Copyright (C) 1999, Mozilla.  All Rights Reserved.
 * 
 * Contributor(s):
 *   Travis Bogard <travis@netscape.com>
 */

#include "nsISupports.idl"

interface nsIDocShellTreeItem;


/**
 * nsIDocShellTreeItemTmp is a temporary internal interface used only
 * to provide a changed signature for the findItemWithName() method to
 * fix problems where DOM windows were reachable across domains.
 */

[scriptable, uuid(9af94896-03fd-4646-bfc0-7b589cfe9dd5)]
interface nsIDocShellTreeItemTmp : nsISupports
{
  /*
    Returns the docShellTreeItem with the specified name.  Search order is as 
    follows...
    1.)  Check name of self, if it matches return it.
    2.)  For each immediate child.
        a.) Check name of child and if it matches return it.
        b.) Ask the child to perform the check
            i.) Do not ask a child if it is the aRequestor
            ii.) Do not ask a child if it is of a different item type.
    3.)  If there is a parent of the same item type ask parent to perform the check
        a.) Do not ask parent if it is the aRequestor
    4.)  If there is a tree owner ask the tree owner to perform the check
        a.) Do not ask the tree owner if it is the aRequestor
        b.) This should only be done if there is no parent of the same type.

    Return the child DocShellTreeItem with the specified name.
    name - This is the name of the item that is trying to be found.
    aRequestor - This is the object that is requesting the find.  This
        parameter is used to identify when the child is asking its parent to find
        a child with the specific name.  The parent uses this parameter to ensure
        a resursive state does not occur by not again asking the requestor to find
        a shell by the specified name.  Inversely the child uses it to ensure it
        does not ask its parent to do the search if its parent is the one that
        asked it to search.  Children also use this to test against the treeOwner;
    aOriginalRequestor - The original treeitem that made the request, if any.
        This is used to ensure that we don't run into cross-site issues.
  */
  nsIDocShellTreeItem findItemWithNameTmp(in wstring name,
                                          in nsISupports aRequestor,
                                          in nsIDocShellTreeItem aOriginalRequestor);
};

