/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIProfileSharingSetup.idl
 */

#ifndef __gen_nsIProfileSharingSetup_h__
#define __gen_nsIProfileSharingSetup_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIProfileSharingSetup */
#define NS_IPROFILESHARINGSETUP_IID_STR "2f977d57-5485-11d4-87e2-0010a4e75ef2"

#define NS_IPROFILESHARINGSETUP_IID \
  {0x2f977d57, 0x5485, 0x11d4, \
    { 0x87, 0xe2, 0x00, 0x10, 0xa4, 0xe7, 0x5e, 0xf2 }}

class NS_NO_VTABLE nsIProfileSharingSetup : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IPROFILESHARINGSETUP_IID)

  /**
   * enableSharing must be called by the application in order to use
   * profile sharing. It should be called as early as possible in the
   * startup sequence - before any use of profile data. If enabled,
   * sharing is enabled for all modules that support it.
   * 
   * @param aClientName   A non-versioned identifier of the current
   *                      application within the suite of applications
   *                      which share this profile. It is used to separate
   *                      the client's non-shared data from shared data
   *                      within the profile directory. Example: "browser"
   *                      or "mail" - not "ProductX 1.3b5"
   */
  /* void enableSharing (in AString aClientName); */
  NS_IMETHOD EnableSharing(const nsAString & aClientName) = 0;

  /**
   * sharingEnabled and clientName
   *
   * Attributes to be used by sharing-enabled components
   */
  /* readonly attribute boolean isSharingEnabled; */
  NS_IMETHOD GetIsSharingEnabled(PRBool *aIsSharingEnabled) = 0;

  /* readonly attribute AString clientName; */
  NS_IMETHOD GetClientName(nsAString & aClientName) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPROFILESHARINGSETUP \
  NS_IMETHOD EnableSharing(const nsAString & aClientName); \
  NS_IMETHOD GetIsSharingEnabled(PRBool *aIsSharingEnabled); \
  NS_IMETHOD GetClientName(nsAString & aClientName); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPROFILESHARINGSETUP(_to) \
  NS_IMETHOD EnableSharing(const nsAString & aClientName) { return _to EnableSharing(aClientName); } \
  NS_IMETHOD GetIsSharingEnabled(PRBool *aIsSharingEnabled) { return _to GetIsSharingEnabled(aIsSharingEnabled); } \
  NS_IMETHOD GetClientName(nsAString & aClientName) { return _to GetClientName(aClientName); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPROFILESHARINGSETUP(_to) \
  NS_IMETHOD EnableSharing(const nsAString & aClientName) { return !_to ? NS_ERROR_NULL_POINTER : _to->EnableSharing(aClientName); } \
  NS_IMETHOD GetIsSharingEnabled(PRBool *aIsSharingEnabled) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsSharingEnabled(aIsSharingEnabled); } \
  NS_IMETHOD GetClientName(nsAString & aClientName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetClientName(aClientName); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsProfileSharingSetup : public nsIProfileSharingSetup
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPROFILESHARINGSETUP

  nsProfileSharingSetup();

private:
  ~nsProfileSharingSetup();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsProfileSharingSetup, nsIProfileSharingSetup)

nsProfileSharingSetup::nsProfileSharingSetup()
{
  /* member initializers and constructor code */
}

nsProfileSharingSetup::~nsProfileSharingSetup()
{
  /* destructor code */
}

/* void enableSharing (in AString aClientName); */
NS_IMETHODIMP nsProfileSharingSetup::EnableSharing(const nsAString & aClientName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isSharingEnabled; */
NS_IMETHODIMP nsProfileSharingSetup::GetIsSharingEnabled(PRBool *aIsSharingEnabled)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AString clientName; */
NS_IMETHODIMP nsProfileSharingSetup::GetClientName(nsAString & aClientName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIProfileSharingSetup_h__ */
