/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIXRemoteClient.idl
 */

#ifndef __gen_nsIXRemoteClient_h__
#define __gen_nsIXRemoteClient_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIXRemoteClient */
#define NS_IXREMOTECLIENT_IID_STR "0bafc924-1dd2-11b2-8345-b59762ae0df7"

#define NS_IXREMOTECLIENT_IID \
  {0x0bafc924, 0x1dd2, 0x11b2, \
    { 0x83, 0x45, 0xb5, 0x97, 0x62, 0xae, 0x0d, 0xf7 }}

class NS_NO_VTABLE nsIXRemoteClient : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IXREMOTECLIENT_IID)

  /**
   * Initializes the client
   */
  /* void init (); */
  NS_IMETHOD Init(void) = 0;

  /**
   * Sends a command to a running instance.  If it returns false then
   * there is no running instance.
   *
   * @param aProgram This is the preferred program that we want to use
   * for this particular command.
   *
   * @param aNoProgramFallback This boolean attribute tells the client
   * code that if the preferred program isn't found that it should
   * fail not send the command to another server.
   *
   * @param aUsername This allows someone to only talk to an instance
   * of the server that's running under a particular username.  If
   * this isn't specified here it's pulled from the LOGNAME
   * environmental variable if it's set.

   * @param aProfile This allows you to specify a particular server
   * running under a named profile.  If it is not specified the
   * profile is not checked.

   * @param aCommand This is the command that is passed to the server.
   * Please see the additional information located at:
   * http://www.mozilla.org/unix/remote.html
   *
   * @param aResponse If there is a response, it will be here.  This
   * includes error messages.  The string is allocated using stdlib
   * string functions, so free it with free().
  */
  /* boolean sendCommand (in string aProgram, in string aUsername, in string aProfile, in string aCommand, out string aResponse); */
  NS_IMETHOD SendCommand(const char *aProgram, const char *aUsername, const char *aProfile, const char *aCommand, char **aResponse, PRBool *_retval) = 0;

  /**
   * Shuts down the client
   */
  /* void shutdown (); */
  NS_IMETHOD Shutdown(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIXREMOTECLIENT \
  NS_IMETHOD Init(void); \
  NS_IMETHOD SendCommand(const char *aProgram, const char *aUsername, const char *aProfile, const char *aCommand, char **aResponse, PRBool *_retval); \
  NS_IMETHOD Shutdown(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIXREMOTECLIENT(_to) \
  NS_IMETHOD Init(void) { return _to Init(); } \
  NS_IMETHOD SendCommand(const char *aProgram, const char *aUsername, const char *aProfile, const char *aCommand, char **aResponse, PRBool *_retval) { return _to SendCommand(aProgram, aUsername, aProfile, aCommand, aResponse, _retval); } \
  NS_IMETHOD Shutdown(void) { return _to Shutdown(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIXREMOTECLIENT(_to) \
  NS_IMETHOD Init(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(); } \
  NS_IMETHOD SendCommand(const char *aProgram, const char *aUsername, const char *aProfile, const char *aCommand, char **aResponse, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->SendCommand(aProgram, aUsername, aProfile, aCommand, aResponse, _retval); } \
  NS_IMETHOD Shutdown(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Shutdown(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsXRemoteClient : public nsIXRemoteClient
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIXREMOTECLIENT

  nsXRemoteClient();

private:
  ~nsXRemoteClient();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsXRemoteClient, nsIXRemoteClient)

nsXRemoteClient::nsXRemoteClient()
{
  /* member initializers and constructor code */
}

nsXRemoteClient::~nsXRemoteClient()
{
  /* destructor code */
}

/* void init (); */
NS_IMETHODIMP nsXRemoteClient::Init()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean sendCommand (in string aProgram, in string aUsername, in string aProfile, in string aCommand, out string aResponse); */
NS_IMETHODIMP nsXRemoteClient::SendCommand(const char *aProgram, const char *aUsername, const char *aProfile, const char *aCommand, char **aResponse, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void shutdown (); */
NS_IMETHODIMP nsXRemoteClient::Shutdown()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIXRemoteClient_h__ */
