/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is the Netscape security libraries.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are 
 * Copyright (C) 2000 Netscape Communications Corporation.  All
 * Rights Reserved.
 * 
 * Contributor(s):
 * 
 * Alternatively, the contents of this file may be used under the
 * terms of the GNU General Public License Version 2 or later (the
 * "GPL"), in which case the provisions of the GPL are applicable 
 * instead of those above.  If you wish to allow use of your 
 * version of this file only under the terms of the GPL and not to
 * allow others to use your version of this file under the MPL,
 * indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by
 * the GPL.  If you do not delete the provisions above, a recipient
 * may use your version of this file under either the MPL or the
 * GPL.
 *
 */

#include "nsISupports.idl"

[scriptable, uuid(6c143dac-bd65-4333-b594-7ed1e748e0f9)]
interface nsINSSCertCache : nsISupports {

  /*
   * cacheAllCerts
   *
   * Creates a cache of all certificates currently known to NSS.
   */
  void cacheAllCerts();

  /*
   * getCachedCerts
   *
   * Returns the cached CERTCertList*
   */
  [notxpcom, noscript] voidPtr getCachedCerts();
};

%{C++

#define NS_NSSCERTCACHE_CID { /* 3f429a14-dffe-417d-8cb8-fdf09bacd09e */ \
    0x3f429a14,                                                          \
    0xdffe,                                                              \
    0x417d,                                                              \
    {0x8c, 0xb8, 0xfd, 0xf0, 0x9b, 0xac, 0xd0, 0x9e}                     \
  }

#define NS_NSSCERTCACHE_CONTRACTID "@mozilla.org/security/nsscertcache;1"

%}
